from dataclasses import dataclass
from typing import List

from arcor2 import rest
from arcor2.data.common import ActionMetadata

from dataclasses_jsonschema import JsonSchemaMixin

from .kinali_abstract_object import KinaliAbstractObject


@dataclass
class StatisticValue(JsonSchemaMixin):

    value: float
    created: int


class Statistic(KinaliAbstractObject):
    """
    Statistic Web API Reference.
    """

    _ABSTRACT = False

    def get_names(self, group_id: str) -> List[str]:
        """
        Gets names of all tracked values stored in given group.
        :param group_id:
        :return:
        """
        return rest.get_list_primitive(f"{self.settings.url}/values/{group_id}", str)

    def add_value(self, group_id: str, name: str, value: float) -> None:
        """
        Logs value with the specified group and name.
        :param group_id:
        :param name:
        :param value:
        :return:
        """

        rest.put(f"{self.settings.url}/values", params={"group_id": group_id, "name": name, "value": value})

    def get_groups(self) -> List[str]:
        """
        Gets Ids of all stored groups.
        :param name:
        :return:
        """

        return rest.get_list_primitive(f"{self.settings.url}/values", str)

    def get_values(self, group_id: str, name: str, since_timestamp: int = 0) -> List[StatisticValue]:
        """
        Gets tracked values with the specified name. Values are sorted as were added to service.
        :param group_id: Logged value name.
        :param name: Logged value name.
        :param since_timestamp: The date and time, as a UNIX timestamp in nanoseconds, after which created values
                                are returned.
        :return:
        """

        return rest.get_list(f"{self.settings.url}/values/{group_id}/{name}", StatisticValue,
                             params={"since_timestamp": since_timestamp})

    def delete_group(self, group_id: str) -> None:
        """
        Deletes all tracked values stored in given group.
        :param group_id:
        :return:
        """

        rest.delete(f"{self.settings.url}/values/{group_id}")

    get_names.__action__ = ActionMetadata(blocking=True)  # type: ignore
    add_value.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_groups.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_values.__action__ = ActionMetadata(blocking=True)  # type: ignore
    delete_group.__action__ = ActionMetadata(blocking=True)  # type: ignore



from dataclasses import dataclass
from typing import Callable, List, Set, TYPE_CHECKING, TypeVar

from arcor2 import DynamicParamTuple as DPT, rest
from arcor2.data.common import ActionMetadata, Joint, Orientation, Pose, Position, ProjectRobotJoints, StrEnum
from arcor2.data.object_type import MeshFocusAction
from arcor2.parameter_plugins.relative_pose import RelativePose

from dataclasses_jsonschema import JsonSchemaMixin

from .kinali_abstract_robot import KinaliAbstractRobot


# mypy work-around by GvR (https://github.com/python/mypy/issues/5107#issuecomment-529372406)
if TYPE_CHECKING:
    F = TypeVar('F', bound=Callable)

    def lru_cache(maxsize: int = 128, typed: bool = False) -> Callable[[F], F]:
        pass
else:
    from functools import lru_cache


class MoveTypeEnum(StrEnum):

    AVOID_COLLISIONS: str = "AvoidCollisions"
    LINE: str = "Line"
    SIMPLE: str = "Simple"


@dataclass
class MoveRelativeParameters(JsonSchemaMixin):

    pose: Pose
    position: Position  # relative position
    orientation: Orientation  # relative orientation


@dataclass
class MoveRelativeJointsParameters(JsonSchemaMixin):

    joints: List[Joint]
    position: Position  # relative position
    orientation: Orientation  # relative orientation


class KinaliRobot(KinaliAbstractRobot):
    """
    REST interface to the robot service.
    """

    _ABSTRACT = False

    def move_to_pose(self, end_effector_id: str, target_pose: Pose, speed: float) -> None:

        rest.put(f"{self.settings.url}/endeffectors/{end_effector_id}/move", target_pose,
                 {"moveType": MoveTypeEnum.AVOID_COLLISIONS.value, "speed": speed})

    def move_to_joints(self, target_joints: List[Joint], speed: float) -> None:

        rest.put(f"{self.settings.url}/joints", target_joints,
                 {"moveType": MoveTypeEnum.AVOID_COLLISIONS.value, "speed": speed})

    def stop(self) -> None:
        rest.put(f"{self.settings.url}/stop")

    def robot_joints(self) -> List[Joint]:
        return rest.get_list(f"{self.settings.url}/joints", Joint)

    @lru_cache()
    def get_end_effectors_ids(self) -> Set[str]:
        return set(rest.get_data(f"{self.settings.url}/endeffectors"))

    def get_end_effector_pose(self, end_effector_id: str) -> Pose:
        return rest.get(f"{self.settings.url}/endeffectors/{end_effector_id}/pose", Pose)

    def move(self, end_effector_id: str, pose: Pose, move_type: MoveTypeEnum,
             speed: float = 0.5) -> None:
        """
        Moves the robot's end-effector to a specific pose.
        :param robot_id: Unique robot id.
        :param end_effector_id: Unique end-effector id.
        :param pose: Target pose.
        :param move_type: Type of move.
        :param speed: Speed of move.
        :return:
        """

        assert 0.0 <= speed <= 1.0

        rest.put(f"{self.settings.url}/endeffectors/{end_effector_id}/move", pose,
                 {"moveType": move_type.value, "speed": speed})

    def move_relative(self, end_effector_id: str, pose: Pose, rel_pose: RelativePose,
                      move_type: MoveTypeEnum, speed: float = 0.5) -> None:
        """
        Moves the robot's end-effector to a specific pose.
        :param robot_id: Unique robot id.
        :param end_effector_id: Unique end-effector id.
        :param pose: Target pose.
        :param rel_pose: Relative pose.
        :param move_type: Type of move.
        :param speed: Speed of move.
        :return:
        """

        assert 0.0 <= speed <= 1.0

        body = MoveRelativeParameters(pose, rel_pose.position, rel_pose.orientation)
        rest.put(f"{self.settings.url}/endeffectors/{end_effector_id}/moveRelative", body,
                 {"moveType": move_type.value, "speed": speed})

    def move_relative_joints(self, end_effector_id: str, joints: ProjectRobotJoints,
                             rel_pose: RelativePose, move_type: MoveTypeEnum, speed: float = 0.5) -> None:
        """
        Moves the robot's end-effector relatively to specific joint values.
        :param robot_id: Unique robot id.
        :param end_effector_id: Unique end-effector id.
        :param joints: Target joints.
        :param rel_pose: Relative pose.
        :param move_type: Type of move.
        :param speed: Speed of move.
        :return:
        """

        assert 0.0 <= speed <= 1.0

        body = MoveRelativeJointsParameters(joints.joints, rel_pose.position, rel_pose.orientation)
        rest.put(f"{self.settings.url}/endeffectors/{end_effector_id}/moveRelativeJoints", body,
                 {"moveType": move_type.value, "speed": speed})

    def set_joints(self, joints: ProjectRobotJoints, move_type: MoveTypeEnum,
                   speed: float = 0.5) -> None:

        assert 0.0 <= speed <= 1.0
        # assert robot_id == joints.robot_id
        rest.put(f"{self.settings.url}/joints", joints.joints, {"moveType": move_type.value, "speed": speed})

    @lru_cache()
    def inputs(self) -> Set[str]:
        return set(rest.get_data(f"{self.settings.url}/inputs"))

    @lru_cache()
    def outputs(self) -> Set[str]:
        return set(rest.get_data(f"{self.settings.url}/outputs"))

    def get_input(self, input_id: str) -> float:
        return rest.get_primitive(f"{self.settings.url}/inputs/{input_id}", float)

    def set_output(self, output_id: str, value: float) -> None:

        assert 0.0 <= value <= 1.0
        rest.put(f"{self.settings.url}/outputs/{output_id}", params={"value": value})

    def get_output(self, output_id: str) -> float:
        return rest.get_primitive(f"{self.settings.url}/outputs/{output_id}", float)

    def focus(self, mfa: MeshFocusAction) -> Pose:
        return rest.put(f"{self.settings.url}/utils/focus", mfa, data_cls=Pose)

    @lru_cache()
    def grippers(self) -> Set[str]:
        return set(rest.get_data(f"{self.settings.url}/grippers"))

    def grip(self, gripper_id: str, position: float = 0.0, speed: float = 0.5, force: float = 0.5) -> \
            None:

        assert 0.0 <= position <= 1.0
        assert 0.0 <= speed <= 1.0
        assert 0.0 <= force <= 1.0

        rest.put(f"{self.settings.url}/grippers/{gripper_id}/grip",
                 params={"position": position, "speed": speed, "force": force})

    def set_opening(self, gripper_id: str, position: float = 1.0, speed: float = 0.5) -> None:

        assert 0.0 <= position <= 1.0
        assert 0.0 <= speed <= 1.0

        rest.put(f"{self.settings.url}/grippers/{gripper_id}/opening",
                 params={"position": position, "speed": speed})

    def get_gripper_opening(self, gripper_id: str) -> float:

        return rest.get_primitive(f"{self.settings.url}/grippers/{gripper_id}/opening", float)

    def is_item_gripped(self, gripper_id: str) -> bool:
        return rest.get_primitive(f"{self.settings.url}/grippers/{gripper_id}/gripped", bool)

    @lru_cache()
    def suctions(self) -> Set[str]:
        return set(rest.get_data(f"{self.settings.url}/suctions"))

    def suck(self, suction_id: str) -> None:
        rest.put(f"{self.settings.url}/suctions/{suction_id}/suck")

    def release(self, suction_id: str) -> None:
        rest.put(f"{self.settings.url}/suctions/{suction_id}/release")

    def is_item_attached(self, suction_id: str) -> bool:
        return rest.get_primitive(f"{self.settings.url}/suctions/{suction_id}/attached", bool)

    move.__action__ = ActionMetadata(blocking=True)  # type: ignore
    move_relative.__action__ = ActionMetadata(blocking=True)  # type: ignore
    move_relative_joints.__action__ = ActionMetadata(blocking=True)  # type: ignore
    set_joints.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_input.__action__ = ActionMetadata(blocking=True)  # type: ignore
    set_output.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_output.__action__ = ActionMetadata(blocking=True)  # type: ignore
    grip.__action__ = ActionMetadata(blocking=True)  # type: ignore
    set_opening.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_gripper_opening.__action__ = ActionMetadata(blocking=True)  # type: ignore
    is_item_gripped.__action__ = ActionMetadata(blocking=True)  # type: ignore
    suck.__action__ = ActionMetadata(blocking=True)  # type: ignore
    release.__action__ = ActionMetadata(blocking=True)  # type: ignore
    is_item_attached.__action__ = ActionMetadata(blocking=True)  # type: ignore


KinaliRobot.DYNAMIC_PARAMS = {
    "end_effector_id": DPT(KinaliRobot.get_end_effectors_ids.__name__, set()),
    "gripper_id": DPT(KinaliRobot.grippers.__name__, set()),
    "suction_id": DPT(KinaliRobot.suctions.__name__, set()),
    "input_id": DPT(KinaliRobot.inputs.__name__, set()),
    "output_id": DPT(KinaliRobot.outputs.__name__, set())
}

KinaliRobot.CANCEL_MAPPING = {
    KinaliRobot.move.__name__: KinaliRobot.stop.__name__,
    KinaliRobot.move_relative.__name__: KinaliRobot.stop.__name__,
    KinaliRobot.move_relative_joints.__name__: KinaliRobot.stop.__name__,
    KinaliRobot.set_joints.__name__: KinaliRobot.stop.__name__
}



from typing import List

from arcor2 import rest
from arcor2.data.common import ActionMetadata

from arcor2_kinali.object_types.kinali_abstract_object import KinaliAbstractObject


class Barcode(KinaliAbstractObject):
    """
    REST interface to the barcode service.
    """

    _ABSTRACT = False

    def active_scanners(self) -> List[str]:
        """
        Gets scanners ids.
        :return:
        """
        return rest.get_list_primitive(f"{self.settings.url}/scanners", str)

    def scan(self, scanner_id: str) -> str:
        """
        Gets scan.
        :param scanner_id:
        :return:
        """

        return rest.get_primitive(f"{self.settings.url}/scanners/{scanner_id}/scan", str)

    active_scanners.__action__ = ActionMetadata(blocking=True)  # type: ignore
    scan.__action__ = ActionMetadata(blocking=True)  # type: ignore



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from arcor2.object_types.upload import upload_def

from arcor2_kinali.object_types.barcode import Barcode
from arcor2_kinali.object_types.interaction import Interaction
from arcor2_kinali.object_types.kinali_abstract_object import KinaliAbstractObject
from arcor2_kinali.object_types.kinali_abstract_robot import KinaliAbstractRobot
from arcor2_kinali.object_types.kinali_robot import KinaliRobot
from arcor2_kinali.object_types.search import Search
from arcor2_kinali.object_types.statistic import Statistic


def main() -> None:

    upload_def(Barcode)
    upload_def(Interaction)
    upload_def(KinaliAbstractObject)
    upload_def(KinaliAbstractRobot)
    upload_def(KinaliRobot)
    upload_def(Search)
    upload_def(Statistic)


if __name__ == "__main__":
    main()



from dataclasses import dataclass
from typing import Set, cast

from arcor2 import rest
from arcor2.object_types.abstract import Generic, Settings


@dataclass
class KinaliSettings(Settings):
    url: str
    configuration_id: str


class KinaliAbstractObject(Generic):
    """
    Object (without pose) that serves as a base class for standard feature services.
    """

    def __init__(self, obj_id: str, name: str, settings: KinaliSettings) -> None:
        super(KinaliAbstractObject, self).__init__(obj_id, name, settings)
        self._create()

    @property
    def settings(self) -> KinaliSettings:
        return cast(KinaliSettings, super(KinaliAbstractObject, self).settings)

    def cleanup(self) -> None:
        rest.put(f"{self.settings.url}/systems/destroy")

    def _active_configuration(self) -> str:
        return rest.get_primitive(f"{self.settings.url}/systems/active", str)

    def _get_configuration_ids(self) -> Set[str]:
        return set(rest.get_data(f"{self.settings.url}/systems"))

    def _create(self):
        if self._active_configuration() != self.settings.configuration_id:
            rest.put(f"{self.settings.url}/systems/{self.settings.configuration_id}/create")


__all__ = [
    KinaliSettings.__name__,
    KinaliAbstractObject.__name__,
]



from dataclasses import dataclass
from typing import cast

from arcor2 import rest
from arcor2.data.common import Pose
from arcor2.object_types.abstract import Robot, Settings


@dataclass
class KinaliRobotSettings(Settings):
    url: str
    robot_id: str


class KinaliAbstractRobot(Robot):
    """
    Object (with pose) that server as a base for Robot service.

    In future, there might be two objects like this: one for robots with end effectors (Aubo) and one for robots
    without end effectors (simatic).
    """

    def __init__(self, obj_id: str, name: str, pose: Pose, settings: KinaliRobotSettings) -> None:
        super(KinaliAbstractRobot, self).__init__(obj_id, name, pose, settings)
        self._create()

    @property
    def settings(self) -> KinaliRobotSettings:
        return cast(KinaliRobotSettings, super(KinaliAbstractRobot, self).settings)

    def _robot_id(self) -> str:
        return rest.get_primitive(f"{self.settings.url}/systems/robotId", str)

    def _create(self):
        # if self._robot_id() != self.settings.robot_id:
        rest.put(f"{self.settings.url}/systems/robotId", params={"robot_id": self.settings.robot_id})


__all__ = [
    KinaliRobotSettings.__name__,
    KinaliAbstractRobot.__name__
]



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
This is an example of the main script without usage of Resources class.

So far, it is necessary to initialize Scene service (0.1.0) separately - for instance using Swagger UI.
"""

from arcor2.clients import scene_service
from arcor2.data.common import Joint, Pose, ProjectRobotJoints, uid
from arcor2.data.object_type import Box

from arcor2_kinali.object_types.barcode import Barcode
from arcor2_kinali.object_types.interaction import Interaction, NotificationLevelEnum
from arcor2_kinali.object_types.kinali_abstract_object import KinaliSettings
from arcor2_kinali.object_types.kinali_abstract_robot import KinaliRobotSettings
from arcor2_kinali.object_types.kinali_robot import KinaliRobot, MoveTypeEnum
from arcor2_kinali.object_types.search import LogLevel, Search, SearchEngineParameters, SearchLogLevel
from arcor2_kinali.object_types.statistic import Statistic


def main() -> None:

    aubo = KinaliRobot(uid(), "Whatever", Pose(), KinaliRobotSettings("http://127.0.0.1:13000", "aubo"))
    simatic = KinaliRobot(uid(), "Whatever", Pose(), KinaliRobotSettings("http://127.0.0.1:13001", "simatic"))
    barcode = Barcode(uid(), "Whatever", KinaliSettings("http://127.0.0.1:14000", "simulator"))
    search = Search(uid(), "Whatever", KinaliSettings("http://127.0.0.1:12000", "simulator"))
    interaction = Interaction(uid(), "Whatever", KinaliSettings("http://127.0.0.1:17000", "simulator"))
    statistic = Statistic(uid(), "Whatever", KinaliSettings("http://127.0.0.1:16000", "simulator"))

    scene_service.delete_all_collisions()
    scene_service.upsert_collision(Box("box_id", 0.1, 0.1, 0.1), Pose())

    aubo.move("suction", Pose(), MoveTypeEnum.AVOID_COLLISIONS)
    simatic.set_joints(ProjectRobotJoints("", "", "", [Joint("x", 0), Joint("y", 0)]), MoveTypeEnum.SIMPLE)
    barcode.scan("scanned_ir")
    search.set_search_parameters(SearchEngineParameters(search_log_level=SearchLogLevel(LogLevel.DEBUG)))
    search.grab_image()
    interaction.add_notification("Test", NotificationLevelEnum.INFO)
    statistic.get_groups()


if __name__ == "__main__":
    main()



from dataclasses import dataclass
from typing import List, Optional

from PIL.Image import Image  # type: ignore

from arcor2 import rest
from arcor2.data.common import ActionMetadata, Pose, StrEnum

from dataclasses_jsonschema import JsonSchemaMixin

from .kinali_abstract_object import KinaliAbstractObject


@dataclass
class ScoredItem(JsonSchemaMixin):

    id: int
    item_pose: Pose
    search_score: float


@dataclass
class SearchOutput(JsonSchemaMixin):

    items: List[ScoredItem]
    container_pose: Pose


@dataclass
class GripperSetup(JsonSchemaMixin):

    pick_pose: Pose
    pick_speed: float
    pre_pick_opening: float
    pick_grip: float
    pick_force: float


@dataclass
class SearchVisualizationSetup(JsonSchemaMixin):

    container: bool
    space_selector: bool
    estimate: bool
    refine: bool


@dataclass
class SearchSaveInfo(JsonSchemaMixin):

    save_input: bool
    save_visualizations: bool
    path: Optional[str] = None


class LogLevel(StrEnum):

    TRACE: str = "trace"
    DEBUG: str = "debug"
    INFO: str = "info"
    WARN: str = "warn"
    ERROR: str = "error"
    FATAL: str = "fatal"


@dataclass
class SearchLogLevel(JsonSchemaMixin):

    level: LogLevel


@dataclass
class SearchEngineParameters(JsonSchemaMixin):

    visualization_setup: Optional[SearchVisualizationSetup] = None
    search_data_save_info: Optional[SearchSaveInfo] = None
    search_log_level: Optional[SearchLogLevel] = None


class Search(KinaliAbstractObject):
    """
    REST interface to the search service.
    """

    _ABSTRACT = False

    def grab_image(self) -> None:
        """
        Grabs image and stores to internal cache.
        :return:
        """
        rest.put(f"{self.settings.url}/capture/grab")

    def get_image(self) -> Image:
        """
        Gets RGB image from internal cache, if there is any.
        :return:
        """

        return rest.get_image(f"{self.settings.url}/capture/image")

    def get_pose(self) -> Pose:
        """
        Gets capture device pose in actual initialized spatial system space.
        :return:
        """
        return rest.get(f"{self.settings.url}/capture/pose", Pose)

    def put_suction_configuration(self, item_id: str, tool_id: str, poses: List[Pose]) -> None:
        """
        Adds or updates suction pick configuration.
        :param item_id:
        :param tool_id:
        :param poses:
        :return:
        """
        rest.put(f"{self.settings.url}/pick/suctions", poses, {"item_id": item_id, "tool_id": tool_id})

    def get_pick_poses_for_suction(self, item_id: str, tool_id: str, pose: Pose) -> List[Pose]:
        """
        Gets pick poses for specific suction and item.
        :param item_id:
        :param tool_id:
        :param pose:
        :return:
        """

        return rest.get_list(f"{self.settings.url}/pick/suctions/poses", Pose, pose,
                             params={"item_id": item_id, "tool_id": tool_id})

    def put_gripper_configuration(self, item_id: str, tool_id: str, gripper_setup: List[GripperSetup]) -> None:
        """
        Adds or updates gripper definitions for tool and item.
        :param item_id:
        :param tool_id:
        :param gripper_setup:
        :return:
        """

        rest.put(f"{self.settings.url}/pick/grippers", gripper_setup, {"item_id": item_id, "tool_id": tool_id})

    def get_pick_poses_for_gripper(self, item_id: str, tool_id: str, pose: Pose) -> List[GripperSetup]:
        """
        Gets pick poses for specific tool and item.
        :param item_id:
        :param tool_id:
        :param pose:
        :return:
        """

        return rest.get_list(f"{self.settings.url}/pick/grippers/setup", GripperSetup, pose,
                             {"item_id": item_id, "tool_id": tool_id})

    def search(self) -> SearchOutput:
        """
        Searches items based on search engine configuration and images stored in internal cache.
        :return:
        """
        return rest.get(f"{self.settings.url}/search", SearchOutput)

    def set_search_parameters(self, parameters: SearchEngineParameters) -> None:
        """
        Sets the search parameters.
        :param parameters:
        :return:
        """

        rest.put(f"{self.settings.url}/search", parameters)

    def visualization(self) -> Image:
        """
        Gets RGB visualization from last search run, if there is any.
        :return:
        """

        return rest.get_image(f"{self.settings.url}/search/visualization")

    grab_image.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_image.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_pose.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_pick_poses_for_suction.__action__ = ActionMetadata(blocking=True)  # type: ignore
    search.__action__ = ActionMetadata(blocking=True)  # type: ignore
    visualization.__action__ = ActionMetadata(blocking=True)  # type: ignore



from dataclasses import dataclass
from typing import List

from arcor2 import rest
from arcor2.data.common import ActionMetadata, StrEnum

from dataclasses_jsonschema import JsonSchemaMixin

from .kinali_abstract_object import KinaliAbstractObject


class NotificationLevelEnum(StrEnum):

    INFO: str = "Info"
    WARN: str = "Warn"
    ERROR: str = "Error"


@dataclass
class DialogValue(JsonSchemaMixin):

    title: str
    content: str
    options: List[str]


@dataclass
class NotificationValue(JsonSchemaMixin):

    message: str
    level: NotificationLevelEnum
    created: int


class Interaction(KinaliAbstractObject):
    """
    REST interface to the barcode service.
    """

    _ABSTRACT = False

    def add_dialog(self, title: str, content: str, options: List[str]) -> None:
        """
        Logs value with the specified group and name.
        :param title:
        :param content:
        :param options:
        :return:
        """

        rest.put(f"{self.settings.url}/dialog", params={"title": title, "content": content}, data=options)

    def get_dialog(self) -> DialogValue:
        """
        Gets names of all tracked values stored in given group.
        :return:
        """

        return rest.get(f"{self.settings.url}/dialog", DialogValue)

    def add_dialog_resolve(self, option: str) -> None:
        """
        Logs value with the specified group and name.
        :param option:
        :return:
        """

        rest.put(f"{self.settings.url}/dialog/resolve", params={"option": option})

    def add_notification(self, message: str, level: NotificationLevelEnum) -> None:
        """
        Logs value with the specified group and name.
        :param message:
        :param level:
        :return:
        """

        rest.put(f"{self.settings.url}/notification", params={"message": message, "level": level})

    def delete_notifications(self) -> None:
        """
        Deletes all tracked values stored in given group.
        :return:
        """

        rest.delete(f"{self.settings.url}/notifications")

    def get_notifications(self, since_imestamp: int) -> List[NotificationValue]:
        """
        Gets names of all tracked values stored in given group.
        :param since_imestamp:
        :return:
        """
        return rest.get_list(f"{self.settings.url}/notifications",
                             NotificationValue, params={"since_imestamp": since_imestamp})

    add_dialog.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_dialog.__action__ = ActionMetadata(blocking=True)  # type: ignore
    add_dialog_resolve.__action__ = ActionMetadata(blocking=True)  # type: ignore
    add_notification.__action__ = ActionMetadata(blocking=True)  # type: ignore
    delete_notifications.__action__ = ActionMetadata(blocking=True)  # type: ignore
    get_notifications.__action__ = ActionMetadata(blocking=True)  # type: ignore



# coding: utf-8


from setuptools import setup, find_packages  # type: ignore

setup(
    name='arcor2_kinali',
    version_config={
        "template": "{tag}.dev{cc}",
        "starting_version": "0.1.0"
    },
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    package_data={"arcor2_kinali": ["py.typed"]},
    url='',
    license='',
    author='Robo@FIT',
    author_email='imaterna@fit.vut.cz',
    description='',
    setup_requires=['another-setuptools-git-version'],
    install_requires=[
        'dataclasses',
        'dataclasses-jsonschema[fast-validation]',
        'arcor2>=0.8.0b6.*',
        'Pillow'
    ],
    zip_safe=False,
)
